# Program: make_ebase_copies.pl
# Author:  Larry Bednar, 3226 NE 24th Ave., Portland OR 97212
#          503-493-8542
#
# Purpose: This Perl program is designed to place a copy of Ebase
#          files located in one sibling directory into another 
#          sibling directory and alter their names to clarify that
#          these are not the original files. 
#
#          This program is intended for use 
#
# Details: The program expects Perl to be installed on the machine from
#          which it is run.
#
#          Due to use of the "back slash" character for special 
#          purposes in Perl, it is probably
#          best for the user to provide path specifications which
#          use back slashes.
#
#          The program expects to be run as part of the "Ebase data
#          transfer tool" application.  As such, it expects to be run
#          from the directory "edtt_new", and assumes file copies are
#          to be placed in sibling directory "edtt_old".  The only
#          unknowns are the name of the sibling directory that contains
#          the source files (for which the user will be prompted), and
#          the naming pattern of the source files (provided as an
#          argument at script invocation).  
#
#          This program is intended for use in MS-DOS/Windows
#          operating systems.  The "directory path" specification
#          features of this program will not function correctly
#          in Unix, Linux, or Macintosh operating systems, although
#          it should be relatively easy to extend this program to 
#          run in those environments.
#
# $RCSfile: make_ebase_copies.pl,v $ 
# $Revision: 1.6 $ 
# $Date: 2002/07/25 02:09:00 $   
# $Author: lbednar $
#  
#
# NOTE: It may be desirable to use single quotes to enclose a 
#       directory path specification, as this clarifies the use of path
#       specifications that include spaces
# EXAMPLE: 'c:/Program Files/WinZip/'

use File::Copy;
use File::Basename;
$os_string = "MSDOS";

# Notify user that program is running
print "\n\nProgram MAKE_EBASE_COPIES.PL started\n\n";
print "This program is designed to create copies of Ebase files\n";
print "  for use by the 'Ebase Data Transfer Tool' application\n\n";

# Specify destination directory for copies, directory for edtt files
$des_dir      = "..\\edtt_old";
$edtt_new_dir = "..\\edtt_new";

# Prompt user for name of sibling directory holding Ebase files and
# limit user to 5 attempts at specifying an existing sibling directory
$loops_left = 5;
do {
    print "\nEnter name of sibling folder holding Ebase data files";
    print "\n   ($loops_left tries allowed)\n";
    chomp($user_response = <STDIN>);
    $src_dir = "..\\" . $user_response;
    if ($user_response 
        and not $src_dir eq $des_dir
        and not $src_dir eq $edtt_new_dir) {
        $sibling_dir = -d $src_dir;
    }
    if (not $sibling_dir) {
        print "\n\n'$user_response' is not a valid source directory\n";
        print "\nSpecified directory must be a sibling directory to '$edtt_new_dir' and";
        print "\nmay not be '$des_dir' or '$edtt_new_dir'";
        print "\n\nDo you want to try again? ([return]='yes',other='no')\n";
        chomp($user_abort=<STDIN>);
    }
    else {
        print "\nDirectory specification '$user_response' accepted\n";
    }
    --$loops_left;
} until ($sibling_dir or $user_abort or $loops_left<1);

#Notify user if excess arguments have been provided
if ($#ARGV > 0) {
    print "More than one argument provided - only 1st will be used";
}

# If invocation argument is provided, interpret as name pattern
# for files to be archived
if ($ARGV[0]) {
    $src_pat = "$ARGV[0]";
}
else {
    $src_pat = '*.103';
}

# Print directory and file specs for user review
print "\n\nThe following specifications are being used\n\n";
print "   Source dir:               ".$src_dir   . "\n";
print "   Source file name pattern: ".$src_pat   . "\n\n";
print "   Target dir:               ".$des_dir   . "\n";

# Allow user to stop program if something is wrong
print "\n\nAll info correct/continue? (<return>='yes', anything else='no')\n";
$user_response = <STDIN>;
chomp $user_response;
#print "User response is '$user_response'\n";

if ($user_response or $user_response eq "0") {
    print "\nProgram stopped in response to user input\n\n";
} 
else {

    fileparse_set_fstype($os_string);

    # Create list of matching files in destination folder
    @filelist = glob("$des_dir" . "\\" . "$src_pat");

    # Delete matching files in destination folder
    unlink @filelist;

    # Create list of files matching source name pattern
    @filelist = glob("$src_dir" . "\\" . "$src_pat");

    # Copy all files
    foreach $src_file (@filelist) {
        ($name,$path,$suffix) = fileparse("$src_file");
        $target_file = "$des_dir\\$name";
        $status = copy($src_file, $target_file);
        if ($status) {
            print "\n        Old file: $src_file\n";
            print "        New file: $target_file\n";
        }
        else {
            print "\nERROR: problem copying file '$src_file'\n";
        }
    }

}

# Display window until user is done reviewing
print "\n\nClose window? (any response with a return = 'yes')\n";
$user_response = <STDIN>;

